﻿-- State Managing
local states = {menu = {},index = {},page = {},settings = {}}
local cState

-- Spirit Database --
local spirits = {}      -- i = string (name), v = the lua file, in other words, a table
local spiritIcons = {}  -- i = string (name), v = quad

-- Graphical Elements --
local wd,ht

local logo
local bg = {}
local fonts = {}
local colors = require 'colors'

-- Arts and Thumbnails --
local spArt = {}
local thumb = {}

--skill icons
local icons = {}

-- Buttons --
local button = require 'button'
local buttons = {}

--text interpreter
local text = require 'text'

function love.load()
    wd,ht = love.graphics.getDimensions()
    
    -- the logo
    logo = love.graphics.newImage('logo.png')
    
    -- background stuff
    bg.img = love.graphics.newImage('bg.png')
    bg.screen = love.graphics.newImage('screen.png')
    bg.img:setWrap('repeat','repeat')
    bg.q = love.graphics.newQuad(0,0,wd,ht,bg.img:getDimensions())
    
    --spirit database
    for _,v in pairs(love.filesystem.getDirectoryItems('spirits')) do
        if string.find(v,'.lua',-4,true) then 
            local index = string.sub(v,1,-5)
            spirits[index] = require('spirits/'..index)
        end
    end
    
    --splash arts and thumbs
    for _,v in pairs(love.filesystem.getDirectoryItems('pics')) do
        if string.find(v,'.jpg',-4,true) then 
            local index = string.sub(v,1,-7)
            local tIndex = tonumber(string.sub(v,-5,-5))
            
            if not spArt[index] then spArt[index] = {} end
            spArt[index][tIndex] = love.graphics.newImage('pics/'..v)
            
            if not thumb[index] then thumb[index] = {} end
            thumb[index][tIndex] = love.graphics.newImage('pics/thumbnails/'..v)
        end
    end
    
    --fonts
    fonts.reg = love.graphics.newFont('fonts/bold.ttf',wd/24)
--    fonts.title1 = love.graphics.newFont('fonts/title2.ttf',wd/10)
    fonts.title1 = love.graphics.newFont('fonts/title1.ttf',wd/15)
--    fonts.title2 = love.graphics.newFont('fonts/title2.ttf',wd/14)
    fonts.title2 = love.graphics.newFont('fonts/title1.ttf',wd/25)
    fonts.dcode = love.graphics.newFont('fonts/dcode.ttf',wd/24)
    
    --spirit icons
    spiritIcons.img2 = love.graphics.newImage('extras/seals1.png')
    spiritIcons.img1 = love.graphics.newImage('extras/seals2.png')
    
    --turn icon
    icons.t = love.graphics.newImage('turn.png')
    
    --start
    states.menu.init()
    cState = 'menu'
end

function love.update(dt)
    states[cState].update(dt)
end
 
function love.draw()
    love.graphics.setColor(255,255,255,50)
    love.graphics.draw(bg.img,bg.q,0,0)
    love.graphics.setColor(unpack(colors.white))
    love.graphics.draw(bg.screen,0,0,0,wd/bg.screen:getWidth(),ht/bg.screen:getHeight())
    
    --digicode above and below
    love.graphics.setFont(fonts.dcode)
    love.graphics.print('^^^^',-5,0)
    love.graphics.print('^^^^',-5,ht - wd/10)
    
    states[cState].draw()
end

function love.mousepressed(x,y,b,touch)
    button.press(buttons[cState],x,y)
end

function love.mousereleased(x,y,b,touch)
    button.release(buttons[cState],x,y)
    if states[cState].mousereleased then states[cState].mousereleased(x,y,b,touch) end
end

function love.keypressed(key)
    if states[cState].keypressed then states[cState].keypressed(key) end
end

local inRect = function (x,y,w,h,px,py)
    --add escape px and py values
	return px >= x and py >= y and px <= x+w and py <= y+h
end

local noToLv = function (n)
    local lvSt = ''
    if n == 1 then lvSt = 'Rookie || HP = 17'
    elseif n == 2 then lvSt = 'Champion || HP = 25'
    elseif n == 3 then lvSt = 'Ultimate || HP = 38'
    elseif n == 4 then lvSt = 'Mega || HP = 58'
    elseif n == 5 then lvSt = 'Burst Mode || HP = 86'
    elseif n == 6 then lvSt = 'Armor || HP = 38'
    elseif n == 7 then lvSt = 'Wonder Armor || HP = 58'
    elseif n == 'human' then lvSt = 'Human || HP = 11'
    end
    return lvSt
end

----------------------------------------------------------------------------------
--                                Menu State                                    --
----------------------------------------------------------------------------------
--                         Just the starting screen                             --
----------------------------------------------------------------------------------
function states.menu.enter()
    if not states.menu.initialized then
        states.menu.init()
    end
end

function states.menu.init()
    buttons.menu = {
        index = {
            x = wd*1/5, y = ht*4/8,
            w = wd*3/5, h = ht*1/8,
            r = 5, color = {n = colors.button, a = colors.abutton, t = colors.white},
            t = 'Index', f = fonts.title1,
            click = function()
                states.index.enter()
                cState = 'index'
                states.index.spirit = 'all'
            end
        },
        settings = {
            x = wd*1/5, y = ht*6/8,
            w = wd*3/5, h = ht*1/8,
            r = 5, color = {n = colors.button, a = colors.abutton, t = colors.white},
            t = 'Settings', f = fonts.title1,
            click = function()
                states.settings.enter()
                cState = 'settings'
            end
        }
    }
    states.menu.initialized = true
end

function states.menu.update(dt) end

function states.menu.draw()
    --logo
    love.graphics.setColor(unpack(colors.white))
    love.graphics.draw(logo,wd/12,ht/8,0,(wd*5/6)/logo:getWidth())
    
    --button
    button.draw(buttons.menu)
end

function states.menu.keypressed(key)
    if key == 'escape' then
        love.event.quit()
    end
end


----------------------------------------------------------------------------------
--                               Index State                                    --
----------------------------------------------------------------------------------
--             Shows all digispirits and the evolution lines                    --
----------------------------------------------------------------------------------
function states.index.enter()
    if not states.index.initialized then
        states.index.init()
    end
end

function states.index.init()
    states.index.icon = wd/4
    states.index.yStart = ht/16 + fonts.title1:getHeight()
    states.index.ySpace = ht - wd/10 - states.index.yStart
    states.index.xSpc = (wd - states.index.icon*2)/5
    states.index.yNo = math.floor((states.index.ySpace - states.index.xSpc)/(states.index.icon + states.index.xSpc))
    states.index.ySpc = (states.index.ySpace - states.index.yNo*states.index.icon)/(states.index.yNo + 1)
    states.index.offset = 0
    
    spiritIcons.size = spiritIcons.img1:getHeight()/4
    spiritIcons.number = 0
    states.index.cSpirit = {}
    for i,v in pairs(spirits) do
        spiritIcons[i] = love.graphics.newQuad(v.icon.x*spiritIcons.size,v.icon.y*spiritIcons.size,
            spiritIcons.size,spiritIcons.size,spiritIcons.img1:getDimensions())
        states.index.cSpirit[i] = 1
        spiritIcons.number = spiritIcons.number + 1
    end
    
    states.index.pages = math.ceil(spiritIcons.number/(states.index.yNo*2))
    
    buttons.index = {
        spPrevious = {
            x = 0, y = states.index.yStart,
            w = states.index.xSpc*1.5, h = states.index.ySpace,
            color = {n = colors.none, a = colors.none},
            click = function()
                if states.index.offset == 0 then
                    states.index.offset = states.index.pages - 1
                else
                    states.index.offset = states.index.offset - 1
                end
            end
        },
        spNext = {
            x = states.index.xSpc*3.5 + states.index.icon*2, y = states.index.yStart,
            w = states.index.xSpc*1.5, h = states.index.ySpace,
            color = {n = colors.none, a = colors.none},
            click = function()
                if states.index.offset == (states.index.pages - 1) then
                    states.index.offset = 0
                else
                    states.index.offset = states.index.offset + 1
                end
            end
        }
    }
    
    local xPos,yPos
    for i=1,states.index.yNo*2 do
        if i % 2 == 0 then 
            xPos = 3*states.index.xSpc + states.index.icon
        else
            xPos = 2*states.index.xSpc
        end
        yPos = states.index.yStart + math.ceil(i/2)*states.index.ySpc + (math.ceil(i/2)-1)*states.index.icon
        buttons.index[i] = {
            x = xPos, y = yPos,
            w = states.index.icon, h = states.index.icon,
            color = {n = colors.none, a = colors.none},
            click = function()
                states.index.spirit = buttons.index[i].spirit
                states.index.evoLineB.sel.disable = true
                buttons.index.spPrevious.disable = true
                buttons.index.spNext.disable = true
                for i,v in ipairs(buttons.index) do
                    v.disable = true
                end
            end
        }
    end
    
    states.index.evoLineB = {}
    states.index.evoLineB.sel = {
        x = 0, y = 0, w = 0, h = 0,
        color = {n = colors.none, a = colors.none},
        click = function()
            states.page.enter(states.index.spirit,states.index.cSpirit[states.index.spirit])
            cState = 'page'
        end
    }
    for i=1,7 do
        states.index.evoLineB[i] = {
            x = 0, y = 0, w = wd/10, h = wd/10,
            color = {n = colors.none, a = colors.none},
            click = function()
                states.index.cSpirit[states.index.spirit] = i
            end
        }
    end
    
    states.index.initialized = true
end

function states.index.update(dt)
    if states.index.offset == (states.index.pages - 1) and not (spiritIcons.number % (states.index.yNo*2) == 0) then
        local disabledB = 6 - (spiritIcons.number % (states.index.yNo*2))
        for i=1,disabledB do
            buttons.index[(states.index.yNo*2)-(i-1)].disable = true
        end
    end
    if states.index.spirit ~= 'all' and love.mouse.isDown(1) 
        and inRect((wd/2)-(states.index.icon/2)/(3/2),0,states.index.icon*2/3,states.index.icon*2/3,love.mouse.getX(),love.mouse.getY()) then
        states.page.enter(states.index.spirit,'human')
        cState = 'page'
    end
end

function states.index.draw()
    if states.index.spirit == 'all' then
        love.graphics.setColor(unpack(colors.white))
        love.graphics.setFont(fonts.title1)
        love.graphics.printf('INDEX',0,ht/16,wd,'center')
        
        local sIndex = 1
        local xPos,yPos
        local cOffset = states.index.offset*states.index.yNo*2
        for i,v in pairs(spirits) do
            if cOffset > 0 then cOffset = cOffset - 1; goto skip end
            
            xPos,yPos = buttons.index[sIndex].x,buttons.index[sIndex].y
            love.graphics.draw(spiritIcons.img1,spiritIcons[i],xPos,yPos,0,(states.index.icon*4)/spiritIcons.img1:getHeight())
            
            buttons.index[sIndex].spirit = i
            buttons.index[sIndex].disable = false
            
            if sIndex == states.index.yNo*2 then break end
            sIndex = sIndex + 1
            
            ::skip::
        end
        
        local vert = {{states.index.xSpc/3,states.index.yStart + states.index.ySpace/2,
                      states.index.xSpc*5/4,states.index.yStart + states.index.ySpace/2 - states.index.xSpc/2,
                      states.index.xSpc*5/4,states.index.yStart + states.index.ySpace/2 + states.index.xSpc/2},
                     {wd - states.index.xSpc/3,states.index.yStart + states.index.ySpace/2,
                      wd - states.index.xSpc*5/4,states.index.yStart + states.index.ySpace/2 - states.index.xSpc/2,
                      wd - states.index.xSpc*5/4,states.index.yStart + states.index.ySpace/2 + states.index.xSpc/2}
        }
        love.graphics.polygon('fill',vert[1])
        love.graphics.polygon('fill',vert[2])
    else
        love.graphics.setColor(0,0,0,150)
        local frac = 3/2
        love.graphics.rectangle('fill',(states.index.icon*2)-((states.index.icon/2)/frac),0,states.index.icon/frac,states.index.icon/frac)
        love.graphics.setColor(unpack(colors.white))
        love.graphics.draw(spiritIcons.img1,spiritIcons[states.index.spirit],(wd/2)-(states.index.icon/2)/frac,0,0,
            (states.index.icon*4/frac)/spiritIcons.img1:getHeight())
        
        local icSp,blSp,skSp = wd/10,wd/20,wd/40
        local xP = blSp
        local yP = states.index.icon/frac + skSp
        for i=1,7 do
            if i == 5 or i == 6 then xP = xP + blSp - skSp end
            if i == states.index.cSpirit[states.index.spirit] then
                love.graphics.setColor(unpack(spirits[states.index.spirit].color))
                local thick = 3
                love.graphics.rectangle('fill',xP-thick,yP-thick,icSp+thick*2,icSp+thick*2)
            end
            love.graphics.setColor(unpack(colors.white))
            love.graphics.draw(thumb[states.index.spirit][i],xP,yP,0,icSp/64)
            states.index.evoLineB[i].x,states.index.evoLineB[i].y = xP,yP
            xP = xP + icSp + skSp
        end
        love.graphics.setColor(unpack(colors.white))
        yP = yP + icSp + skSp
        states.index.aSpc = ht - yP - wd/10
        states.index.evoLineB.sel.w = wd
        states.index.evoLineB.sel.y = yP
        states.index.evoLineB.sel.h = states.index.aSpc
        states.index.evoLineB.sel.disable = false
        
        local img = spArt[states.index.spirit][states.index.cSpirit[states.index.spirit]]
        love.graphics.draw(img,wd/2,yP,0,states.index.aSpc/img:getHeight(),states.index.aSpc/img:getHeight(),img:getWidth()/2,0)
        
        love.graphics.setFont(fonts.title1)
        local name = spirits[states.index.spirit][states.index.cSpirit[states.index.spirit]].name
        local sx = 1
        if love.graphics.getFont():getWidth(name) > (wd) then 
            sx = (wd)/love.graphics.getFont():getWidth(name)
        end
        
        love.graphics.setColor(0,0,0,230)
        love.graphics.rectangle('fill',wd/2-love.graphics.getFont():getWidth(name)/2 - 3,ht-wd/10,love.graphics.getFont():getWidth(name)+6,wd/10)
        
        love.graphics.setColor(unpack(spirits[states.index.spirit].color))
        love.graphics.print(name,wd/2,(ht - wd/10)+(wd/10)/2,0,sx,1,love.graphics.getFont():getWidth(name)/2,love.graphics.getFont():getHeight()/2)
        
    end
    --button
    button.draw(buttons.index)
end

function states.index.keypressed(key)
    if key == 'escape' then
        if states.index.spirit == 'all' then
            states.menu.enter()
            cState = 'menu'
        else
            buttons.index.spPrevious.disable = false
            buttons.index.spNext.disable = false
            states.index.spirit = 'all'
        end
    end
end

function states.index.mousereleased(x,y,b,touch)
    if states.index.spirit ~= 'all' then
        button.release(states.index.evoLineB,x,y)
    end
end

----------------------------------------------------------------------------------
--                                Page State                                    --
----------------------------------------------------------------------------------
--                Shows an individual digimon skill page                        --
----------------------------------------------------------------------------------
function states.page.enter(spirit,level)
    states.page.spirit,states.page.level = spirit,level
    
    if not states.page.initialized then
        states.page.init()
    end
end

function states.page.init()
    --icons
    for _,v in pairs(love.filesystem.getDirectoryItems('icons')) do
        if string.find(v,'.jpg',-4,true) then
            if string.find(v,'_p.jpg',-6,true) then
                local spp = string.sub(v,1,-7)
                icons[spp].p = love.graphics.newImage('icons/'..v)
            else
                local sp = string.sub(v,1,-9)
                local i1 = tonumber(string.sub(v,-7,-7))
                local i2 = tonumber(string.sub(v,-5,-5))
                if not icons[sp] then icons[sp] = {} end
                if not icons[sp][i1] then icons[sp][i1] = {} end
                icons[sp][i1][i2] = love.graphics.newImage('icons/'..v)
            end
        end
    end
    icons.p = love.graphics.newImage('iconP.jpg')
    
    states.page.thumbSE = wd/5
    states.page.thumbS = states.page.thumbSE*9/10
    
    states.page.ySpace = ht - wd*3/10
    states.page.divX = wd*37/80
    states.page.divY = states.page.ySpace/3
    states.page.icoS = states.page.divY/2
    states.page.texH = states.page.divY*7/20
    states.page.ySpS = states.page.divY/20
    states.page.xSpS = wd/40
    states.page.xSkS = (states.page.divX - states.page.icoS)/2
    
    states.page.inYSpace = ht - wd/5
    states.page.inIcoSpc = states.page.inYSpace/40
    states.page.inIcoRow = states.page.inIcoSpc*7
    states.page.inDescSp = states.page.inIcoSpc*30
    
    states.page.pSpc = wd - ht/10 - (states.page.thumbSE-states.page.thumbS)*2
    
    states.page.skillB = {}
    states.page.info = {}
    
    buttons.page = {
        minus = {
            x = 0, y = 0, w = 0, h = 0, t = '-',
            color = {n = colors.none, a = colors.none, t = colors.white},hide = true,
            click = function()
                if buttons.page.number.t > 0 then
                    buttons.page.number.t = buttons.page.number.t - 1
                end
            end
        },
        plus = {
            x = 0, y = 0, w = 0, h = 0, t = '+',
            color = {n = colors.none, a = colors.none, t = colors.white},hide = true,max = 0,
            click = function()
                if buttons.page.number.t < buttons.page.plus.max then
                    buttons.page.number.t = buttons.page.number.t + 1
                end
            end
        },
        number = {
            x = 0, y = 0, w = 0, h = 0, t = 0,
            color = {n = colors.none, a = colors.none, t = colors.white},hide = true
        },
        passive = {
            x = 0, y = 0, w = 0, h = 0, t = 'Passive Name', f = fonts.title1, align = 'left',
            color = {n = colors.none, a = colors.none, t = colors.white},hide = true
        },
        enter = {
            x = 0, y = 0, w = 0, h = 0,
            color = {n = colors.none, a = colors.none},hide = true,
            click = function()
                buttons.page.plus.disable = true
                buttons.page.minus.disable = true
                buttons.page.number.disable = true
                buttons.page.passive.disable = true
                buttons.page.enter.disable = true
                states.page.info.index = 'passive'
                states.page.info.show = true
            end
        }
    }
    
    states.page.initialized = true
end

function states.page.update(dt)
    for i,v in ipairs(spirits[states.page.spirit][states.page.level]) do
        if states.page.skillB[i] then
            buttons.page[i] = {
                x = states.page.skillB[i].x , y = states.page.skillB[i].y, w = states.page.icoS, h = states.page.icoS,
                color = {n = colors.none, a = colors.none},
                click = function()
                    states.page.info.index = i;
                    states.page.info.show = true
                end
            }
        end
    end
    if states.page.info.show then
        for i,v in pairs(buttons.page) do
            v.disable = true
        end
    end
end

function states.page.draw()
    love.graphics.setColor(0,0,0,230)
    love.graphics.rectangle('fill',0,0,states.page.thumbSE,states.page.thumbSE)
    love.graphics.rectangle('fill',0,ht*9/10,wd,ht/10)
    
    local spc = states.page.thumbSE-states.page.thumbS
    local xP = states.page.thumbSE+(spc/2)
    love.graphics.rectangle('fill',xP,0,wd - xP - spc,states.page.thumbSE)
    
    love.graphics.setColor(unpack(colors.white))
    
    if states.page.level == 'human' then
        love.graphics.draw(spiritIcons.img1,spiritIcons[states.page.spirit],spc/2,spc/2,0,
            states.page.thumbS/(spiritIcons.img1:getHeight()/4))
    else
        local thu = thumb[states.page.spirit][states.page.level]
        love.graphics.draw(thu,spc/2,spc/2,0,states.page.thumbS/thu:getWidth())
    end
    
    love.graphics.setFont(fonts.title1)
    love.graphics.setColor(unpack(spirits[states.page.spirit].color))
    local sx = 1
    if love.graphics.getFont():getWidth(spirits[states.page.spirit][states.page.level].name) > (wd - xP - spc - 12) then 
        sx = (wd - xP - spc - 12)/love.graphics.getFont():getWidth(spirits[states.page.spirit][states.page.level].name)
    end
    love.graphics.print(spirits[states.page.spirit][states.page.level].name,xP+spc,spc,0,sx)
    love.graphics.setFont(fonts.title2)
    love.graphics.print('Level: '..noToLv(states.page.level),xP+spc,fonts.title2:getHeight()+spc*2.5)
    
    local xPos,yPos = states.page.xSpS, wd/5
    local rows = math.ceil(#spirits[states.page.spirit][states.page.level]/2)
    yPos = yPos + states.page.ySpace/2 - (rows*states.page.divY)/2
    for i,v in ipairs(spirits[states.page.spirit][states.page.level]) do
        if i == 3 or i == 4 then yPos = yPos + states.page.divY end
        if i == 5 then xPos = wd/2 - states.page.divX/2; yPos = yPos + states.page.divY*2 end 
        
        states.page.skillB[i] = {
            x = xPos+states.page.xSkS+((1-(i%2))*(states.page.xSpS+states.page.xSkS*2+states.page.icoS)),
            y = yPos+states.page.ySpS
        }
        
        love.graphics.setColor(unpack(spirits[states.page.spirit].color))
        local recDrawMode = 'fill'
        if states.page.level == 'human' then recDrawMode = 'line' end
        love.graphics.rectangle(recDrawMode,states.page.skillB[i].x-1,states.page.skillB[i].y-1,states.page.icoS+2,states.page.icoS+2)
        
        local ico
        if icons[states.page.spirit] then
            if icons[states.page.spirit][states.page.level] then
                ico = icons[states.page.spirit][states.page.level][i]
            else
                ico = icons.p 
            end
        else
            ico = icons.p 
        end
        love.graphics.setColor(unpack(colors.white))
        if states.page.level == 'human' then
            love.graphics.draw(spiritIcons.img1,spiritIcons[states.page.spirit],states.page.skillB[i].x,states.page.skillB[i].y,0,
                states.page.icoS/(spiritIcons.img1:getHeight()/4))
        else
            love.graphics.draw(ico,states.page.skillB[i].x,states.page.skillB[i].y,0,states.page.icoS/ico:getWidth())
        end
        
        yPos = yPos + 4 + states.page.icoS + states.page.ySpS
        
        love.graphics.setFont(fonts.title2)
        sx = 1
        if love.graphics.getFont():getWidth(v.name) > (states.page.divX - 8) then 
            sx = (states.page.divX - 8)/love.graphics.getFont():getWidth(v.name)
        end
        
        love.graphics.setColor(unpack(spirits[states.page.spirit].color)) 
        
        love.graphics.print(v.cd,xPos + states.page.xSkS + states.page.icoS + wd/40 + ((1-(i%2))*(states.page.xSpS+states.page.xSkS*2+states.page.icoS)),
            yPos - 2 - states.page.icoS/2 - states.page.ySpS) -- love.graphics.getFont():getHeight()/2)
        
        love.graphics.print(v.name,xPos + states.page.divX/2 +((1-(i%2))*(states.page.xSpS+states.page.divX)),yPos,0,
            sx,1,love.graphics.getFont():getWidth(v.name)/2,0)
        yPos = wd/5 + states.page.ySpace/2 - (rows*states.page.divY)/2
    end
    
    --passive & turn area
    love.graphics.setColor(unpack(colors.white))
    love.graphics.setFont(fonts.title1)
    if spirits[states.page.spirit].passive and spirits[states.page.spirit][states.page.level].passive then
        buttons.page.enter.hide = false
        if spirits[states.page.spirit].passive.number then
            buttons.page.plus.hide = false
            buttons.page.plus.max = spirits[states.page.spirit].passive.max or 0
            buttons.page.minus.hide = false
            buttons.page.passive.hide = true
            buttons.page.number.hide = false
            
            buttons.page.minus.x,buttons.page.minus.y = spc,ht*9/10
            buttons.page.minus.w,buttons.page.minus.h = ht/20,ht/10
            local ico
            if icons[states.page.spirit] then
                if icons[states.page.spirit].p then
                    ico = icons[states.page.spirit].p
                else
                    ico = icons.p 
                end
            else
                ico = icons.p 
            end
            love.graphics.draw(ico,spc*2 + ht/20,ht*9/10,0,(ht/10)/ico:getHeight())
            buttons.page.number.x,buttons.page.number.y = spc*3 + ht/20 + ((ico:getWidth())*(ht/10)/ico:getHeight()),ht*9/10
            buttons.page.number.w,buttons.page.number.h = ht/20,ht/10
            buttons.page.plus.x,buttons.page.plus.y = spc*4 + ht/10 + ((ico:getWidth())*(ht/10)/ico:getHeight()),ht*9/10
            buttons.page.plus.w,buttons.page.plus.h = ht/20,ht/10
            
            buttons.page.enter.x,buttons.page.enter.y = spc*2 + ht/20,ht*9/10
            buttons.page.enter.w,buttons.page.enter.h = ((ico:getWidth())*(ht/10)/ico:getHeight()) + ht/20,ht/10
        else
            buttons.page.enter.x,buttons.page.enter.y = spc,ht*9/10
            buttons.page.enter.w,buttons.page.enter.h = wd - ht/10 - spc*2,ht/10
            local ico
            if icons[states.page.spirit] then
                if icons[states.page.spirit].p then
                    ico = icons[states.page.spirit].p
                else
                    ico = icons.p 
                end
            else
                ico = icons.p 
            end
            love.graphics.draw(ico,spc,ht*9/10,0,(ht/10)/ico:getHeight())
            buttons.page.plus.hide = true
            buttons.page.minus.hide = true
            buttons.page.number.hide = true
            buttons.page.passive.hide = false
            buttons.page.passive.x,buttons.page.passive.y = spc*2 + ht/10, ht*9/10
            buttons.page.passive.w,buttons.page.passive.h = wd - ht*2/10 - spc*2, ht/10
            buttons.page.passive.t = spirits[states.page.spirit].passive.name
            buttons.page.passive.color.t = spirits[states.page.spirit].color
        end
    else
        buttons.page.plus.hide = true
        buttons.page.minus.hide = true
        buttons.page.number.hide = true
        buttons.page.passive.hide = true
        buttons.page.enter.hide = true
    end
    love.graphics.draw(icons.t,wd-ht/10,ht*9/10,0,(ht/10)/icons.t:getWidth())
    
    --button
    button.draw(buttons.page)
    
    if states.page.info.show then
        local spc = states.page.thumbSE-states.page.thumbS
        
        love.graphics.setColor(0,0,0,160)
        love.graphics.rectangle('fill',0,wd/5,wd,ht)
        love.graphics.rectangle('fill',spc*2 + states.page.inIcoRow,wd/5 + states.page.inIcoSpc,wd - spc*3 - states.page.inIcoRow,states.page.inIcoRow)
        love.graphics.rectangle('fill',spc,wd/5 + states.page.inIcoSpc*9,wd - spc*2,states.page.inDescSp)
        
        love.graphics.setColor(unpack(spirits[states.page.spirit].color))
        local recDrawMode = 'fill'
        if states.page.level == 'human' or states.page.info.index == 'passive' then recDrawMode = 'line' end
        love.graphics.rectangle(recDrawMode,spc - 1,wd/5 + states.page.inIcoSpc - 1,states.page.inIcoRow+2,states.page.inIcoRow+2)
        
        love.graphics.setFont(fonts.title1)
        
        local sx = 1
        local digipage = spirits[states.page.spirit][states.page.level][states.page.info.index]
        if love.graphics.getFont():getWidth(digipage.name) > (wd - spc*5 - states.page.inIcoRow) then 
            sx = (wd - spc*5 - states.page.inIcoRow)/love.graphics.getFont():getWidth(digipage.name)
        end
        love.graphics.print(digipage.name,spc*3 + states.page.inIcoRow,wd/5+states.page.inIcoSpc*8-fonts.title1:getHeight()-fonts.title2:getHeight(),0,sx,1)
        
        love.graphics.setFont(fonts.title2)
        if states.page.info.index =='passive' or digipage.cd == 'Passive' then
            love.graphics.print('Passive',spc*3 + states.page.inIcoRow,wd/5+states.page.inIcoSpc*8-fonts.title2:getHeight())
        else
            love.graphics.print('Cooldown = '..digipage.cd,spc*3 + states.page.inIcoRow,wd/5+states.page.inIcoSpc*8-fonts.title2:getHeight())
        end
        
        love.graphics.setColor(unpack(colors.white))
        local ico
        if icons[states.page.spirit] then
            if icons[states.page.spirit][states.page.level] then
                ico = icons[states.page.spirit][states.page.level][states.page.info.index]
            else
                ico = icons.p 
            end
        else 
            ico = icons.p 
        end
        if states.page.level == 'human' or states.page.info.index == 'passive' then
            love.graphics.draw(spiritIcons.img1,spiritIcons[states.page.spirit],spc,wd/5 + states.page.inIcoSpc,0,
                states.page.inIcoRow/(spiritIcons.img1:getHeight()/4))
        else
            love.graphics.draw(ico,spc,wd/5 + states.page.inIcoSpc,0,states.page.inIcoRow/ico:getWidth())
        end
        
        love.graphics.setFont(fonts.reg)
        love.graphics.printf(text.convert(digipage.desc,spirits[states.page.spirit].color),spc*2,wd/5 + states.page.inIcoSpc*10,wd - spc*4,'center')
    end
end

function states.page.keypressed(key)
    if key == 'escape' then
        if not states.page.info.show then
            states.index.enter()
            cState = 'index'
            states.index.evoLineB.sel.disable = true
        else
            states.page.info.show = false
            buttons.page.plus.disable = false
            buttons.page.minus.disable = false
            buttons.page.number.disable = false
            buttons.page.passive.disable = false
            buttons.page.enter.disable = false
        end
    end
end


----------------------------------------------------------------------------------
--                              Settings State                                  --
----------------------------------------------------------------------------------
--                                Not made yet                                  --
----------------------------------------------------------------------------------
function states.settings.enter()
    if not states.settings.initialized then
        states.settings.init()
    end
end

function states.settings.init()
    
    
    
    states.settings.initialized = true
end
function states.settings.update(dt)
    
end

function states.settings.draw()
    
end
function states.settings.keypressed(key)
    if key == 'escape' then
        states.menu.enter()
        cState = 'menu'
    end
end